addLabel: Add labels to a story
Description
Add labels to a story
Usage
addLabel(story, labels = character(0))addLabels(story, labels = character(0))
Arguments
story
A story object, a story id, or URL to a story
labels
Character vector of names of labels to add to the story
Value
Invisibly, the story object with the labels added. If the story
already has all of the labels you're trying to add, no request will be made.